==> haskell-tamarin-prover-export-1.10.0-141-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-tamarin-prover-export.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tamarin-prover-export
version:              1.10.0
visibility:           public
id:                   tamarin-prover-export-1.10.0-9p1AWizJz0G72yolnQpB91
key:                  tamarin-prover-export-1.10.0-9p1AWizJz0G72yolnQpB91
license:              GPL-3.0-only
copyright:
    Robert Künnemann, CISPA-Helmholtz-Centre Saarbrücken, 2019
    Charlie Jacomme, LSV, 2019

maintainer:           Robert Künnemann <robert@kunnemann.de>
author:
    Robert Künnemann <robert@kunnemann.de>,
    Charlie Jacomme <charlie.jacomme@lsv.fr>

homepage:             https://tamarin-prover.github.io/
synopsis:
    Library for export of processes in the Sapic calculus to the Proverif calculus

description:
    This is an internal library of the Tamarin prover for
    security protocol verification
    (<hackage.haskell.org/package/tamarin-prover>).
    .

category:             Theorem Provers
abi:                  1904704e81e043c71e9c8bda3b7a236d
exposed:              True
exposed-modules:      Export
hidden-modules:       RuleTranslation
import-dirs:          /usr/lib/ghc-9.6.6/site-local/tamarin-prover-export-1.10.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/tamarin-prover-export-1.10.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/tamarin-prover-export-1.10.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tamarin-prover-export
hs-libraries:         HStamarin-prover-export-1.10.0-9p1AWizJz0G72yolnQpB91
depends:
    base-4.18.2.1 bytestring-0.11.5.3 containers-0.6.7
    tamarin-prover-sapic-1.10.0-9cYayj69tGjAiM9MIRn3eg
    tamarin-prover-term-1.10.0-8m1cmiZoh6pIs2QTsHMG1e
    tamarin-prover-theory-1.10.0-FQdbJN1HTJM4v4YRI8QIob
    tamarin-prover-utils-1.10.0-Ic9mtk7pOR48tkJCsqQc0x text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-tamarin-prover-export/html/tamarin-prover-export.haddock

haddock-html:         /usr/share/doc/haskell-tamarin-prover-export/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tamarin-prover-export-1.10.0-143-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-tamarin-prover-export.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tamarin-prover-export
version:              1.10.0
visibility:           public
id:                   tamarin-prover-export-1.10.0-H9qgOAOJo2SGTYidxZeXbj
key:                  tamarin-prover-export-1.10.0-H9qgOAOJo2SGTYidxZeXbj
license:              GPL-3.0-only
copyright:
    Robert Künnemann, CISPA-Helmholtz-Centre Saarbrücken, 2019
    Charlie Jacomme, LSV, 2019

maintainer:           Robert Künnemann <robert@kunnemann.de>
author:
    Robert Künnemann <robert@kunnemann.de>,
    Charlie Jacomme <charlie.jacomme@lsv.fr>

homepage:             https://tamarin-prover.github.io/
synopsis:
    Library for export of processes in the Sapic calculus to the Proverif calculus

description:
    This is an internal library of the Tamarin prover for
    security protocol verification
    (<hackage.haskell.org/package/tamarin-prover>).
    .

category:             Theorem Provers
abi:                  45bef1417fadb8e06e085118105b0e61
exposed:              True
exposed-modules:      Export
hidden-modules:       RuleTranslation
import-dirs:          /usr/lib/ghc-9.6.6/site-local/tamarin-prover-export-1.10.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/tamarin-prover-export-1.10.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/tamarin-prover-export-1.10.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tamarin-prover-export
hs-libraries:         HStamarin-prover-export-1.10.0-H9qgOAOJo2SGTYidxZeXbj
depends:
    base-4.18.2.1 bytestring-0.11.5.3 containers-0.6.7
    tamarin-prover-sapic-1.10.0-HJRVcOLrrMzIWKPgyUbp2T
    tamarin-prover-term-1.10.0-DyDW1t62HaM9yQKIJp9NWQ
    tamarin-prover-theory-1.10.0-FISZ0yFoQbtJZJfLjJW8pz
    tamarin-prover-utils-1.10.0-Gv3ExdQ60EpBb0I0m1wL8M text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-tamarin-prover-export/html/tamarin-prover-export.haddock

haddock-html:         /usr/share/doc/haskell-tamarin-prover-export/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
